@@ -41,6 +41,13 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     storelastSearchBox     = new QCheckBox();
     storelastSearchBox->setText(tr("Store last searched stations"));
     storelastSearchBox->setChecked(settings->value("storelastsearch", true).toBool());
+    connect(storelastSearchBox, SIGNAL(stateChanged(int)), this, SLOT(storelastSearchToggled(int)));
+
+    //Store last search
+    prefillSearchBox     = new QCheckBox();
+    prefillSearchBox->setText(tr("Prefill last searched station"));
+    prefillSearchBox->setChecked(settings->value("prefillsearchbox", true).toBool());
+    prefillSearchBox->setEnabled(storelastSearchBox->isChecked());
 
     //Gps early start checkbox
     gpsBox     = new QCheckBox();
@@ -96,6 +103,7 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     vLayout->addWidget(gpsBox);
     vLayout->addWidget(gpsBackendBox);
     vLayout->addWidget(storelastSearchBox);
+    vLayout->addWidget(prefillSearchBox);
     vLayout->addWidget(backendButton);
     vContainer->setLayout(vLayout);
 
@@ -108,11 +116,17 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     setLayout(hLayout);
 }
 
+void configDialog::storelastSearchToggled(int state)
+{
+    prefillSearchBox->setEnabled(storelastSearchBox->isChecked());
+}
+
 void configDialog::okButtonClicked()
 {
     settings->setValue("autostartGPS", gpsBox->isChecked());
     settings->setValue("openstreetmapfallback", gpsBackendBox->isChecked());
     settings->setValue("storelastsearch", storelastSearchBox->isChecked());
+    settings->setValue("prefillsearchbox", prefillSearchBox->isChecked());
 
     if (backendSelector->currentIndex() == 0)
     {
