@@ -1,4 +1,4 @@
 #
 # Regular cron jobs for the fahrplan package
 #
-0 4	* * *	root	fahrplan_maintenance
+#0 4	* * *	root	fahrplan_maintenance
