@@ -20,7 +20,7 @@
     </message>
     <message>
         <location filename="mainwindow.cpp" line="46"/>
-        <location filename="mainwindow.cpp" line="436"/>
+        <location filename="mainwindow.cpp" line="306"/>
         <source>Donate</source>
         <translation>Spenden</translation>
     </message>
@@ -37,7 +37,7 @@
     <message>
         <location filename="mainwindow.cpp" line="66"/>
         <location filename="mainwindow.cpp" line="68"/>
-        <location filename="mainwindow.cpp" line="814"/>
+        <location filename="mainwindow.cpp" line="684"/>
         <source>please select</source>
         <translation>bitte wählen</translation>
     </message>
@@ -82,9 +82,13 @@
         <translation>Willkommen bei einer neuen Version von Fahrplan, dies ist neu</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="198"/>
         <source>- bahn.de: adding train restrictions&lt;br&gt;- Calendar: you can select to which calendar you want add the journey.&lt;br&gt;- last used stationnames could be filled automatically on startup.&lt;br&gt;- Added a Donate link to the mainmenu</source>
-        <translation>- bahn.de: filtern nach Verkehrsmittel&lt;br&gt;-Kalender: Man kann nun wählen zu welchem Kalender man die Verbindung hinzufügen möchte&lt;br&gt;-letzte Haltestelle kann automatisch gefüllt werden&lt;br&gt;Es gibt nun einen Spenden knopf</translation>
+        <translation type="obsolete">- bahn.de: filtern nach Verkehrsmittel&lt;br&gt;-Kalender: Man kann nun wählen zu welchem Kalender man die Verbindung hinzufügen möchte&lt;br&gt;-letzte Haltestelle kann automatisch gefüllt werden&lt;br&gt;Es gibt nun einen Spenden knopf</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="198"/>
+        <source>- bahn.de: fixed gps search&lt;br&gt;- making sure the Birthdays calendar will not be displayed as a valid target calendar.</source>
+        <translation>-bahn.de: fehler mit gps suche behoben&lt;br&gt;- Geburtstags Kalender wird nun nicht mehr als wählbarer kalender angezeigt.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="232"/>
@@ -107,142 +111,186 @@
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;an&lt;/b&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="307"/>
         <source>Journey: </source>
-        <translation>Verbindung: </translation>
+        <translation type="obsolete">Verbindung: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="307"/>
-        <location filename="mainwindow.cpp" line="308"/>
-        <location filename="mainwindow.cpp" line="578"/>
+        <location filename="mainwindow.cpp" line="448"/>
         <source> to </source>
         <translation> nach </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="316"/>
         <source>Duration: </source>
-        <translation>Dauer: </translation>
+        <translation type="obsolete">Dauer: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="353"/>
         <source>
 
 (added by fahrplan app, please recheck informations before travel.)</source>
         <translatorcomment>dont use umlauts!</translatorcomment>
+        <translation type="obsolete">
+
+(hinzugefuegt von Fahrplan, bitte vor Fahrantritt daten erneut pruefen)</translation>
+    </message>
+    <message>
+        <source>&lt;br&gt;Entry is in the past!&lt;br&gt;</source>
+        <translation type="obsolete">&lt;br&gt;Eintrag ist in der Vergangenheit!&lt;br&gt;</translation>
+    </message>
+    <message>
+        <source>&lt;br&gt;Entry added to the </source>
+        <translation type="obsolete">&lt;br&gt;Eintrag wurde zum </translation>
+    </message>
+    <message>
+        <source> calendar.&lt;br&gt;</source>
+        <translation type="obsolete"> Kalender hinzugefügt.&lt;br&gt;</translation>
+    </message>
+    <message>
+        <source>Select target calendar</source>
+        <translation type="obsolete">Ziel Kalender wählen</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="307"/>
+        <source>Thank you for Donating!</source>
+        <translation>Danke fürs spenden!</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="313"/>
+        <source>by smurfy (maemo@smurfy.de)&lt;br&gt;Version </source>
+        <translation>von smurfy (maemo@smurfy.de)&lt;br&gt;Version </translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="313"/>
+        <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
+        <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="315"/>
+        <source>About Fahrplan</source>
+        <translation>Über Fahrplan</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="342"/>
+        <source>&lt;br&gt;Details already loading, please wait.&lt;br&gt;</source>
+        <translation>&lt;br&gt;Details werden bereits geladen, bitte warten.&lt;br&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="356"/>
+        <source>&lt;br&gt;Error opening the details.&lt;br&gt;</source>
+        <translation>&lt;br&gt;Beim öffnen der Details ist ein Fehler aufgetreten.&lt;br&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="362"/>
+        <source>Details</source>
+        <translation>Details</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="371"/>
+        <source>Add to calendar</source>
+        <translation>In Kalender eintragen</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="453"/>
+        <source>&lt;br&gt;&lt;b&gt;Duration: &lt;/b&gt;</source>
+        <translation>&lt;br&gt;&lt;b&gt;Dauer: &lt;/b&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="488"/>
+        <source>&lt;br&gt;No results found.&lt;br&gt;</source>
+        <translation>&lt;br&gt;Keine Ergebnisse gefunden.&lt;br&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="507"/>
+        <source>Results</source>
+        <translation>Ergebnis</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="524"/>
+        <source>to</source>
+        <translation>nach</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="535"/>
+        <source>Earlier</source>
+        <translation>Früher</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="541"/>
+        <source>Later</source>
+        <translation>Später</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="554"/>
+        <source> transfer</source>
+        <translation> umstieg</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="557"/>
+        <source> transfers</source>
+        <translation> umstiege</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="576"/>
+        <source>&lt;br&gt;OnTime</source>
+        <translation>&lt;br&gt;Pünktlich</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="714"/>
+        <source>&lt;br&gt;Please select a from and to station and make sure they are not the same.&lt;br&gt;</source>
+        <translation>&lt;br&gt;Bitte zwei verschiedene Haltestellen wählen.&lt;br&gt;</translation>
+    </message>
+</context>
+<context>
+    <name>calendarDialog</name>
+    <message>
+        <location filename="calendardialog.cpp" line="29"/>
+        <source>Select target calendar</source>
+        <translation>Ziel Kalender wählen</translation>
+    </message>
+    <message>
+        <location filename="calendardialog.cpp" line="136"/>
+        <source>Private</source>
+        <translation>Privat</translation>
+    </message>
+    <message>
+        <location filename="calendardialog.cpp" line="152"/>
+        <source>Journey: </source>
+        <translation>Verbindung: </translation>
+    </message>
+    <message>
+        <location filename="calendardialog.cpp" line="152"/>
+        <location filename="calendardialog.cpp" line="153"/>
+        <source> to </source>
+        <translation> nach </translation>
+    </message>
+    <message>
+        <location filename="calendardialog.cpp" line="161"/>
+        <source>Duration: </source>
+        <translation>Dauer: </translation>
+    </message>
+    <message>
+        <location filename="calendardialog.cpp" line="198"/>
+        <source>
+
+(added by fahrplan app, please recheck informations before travel.)</source>
         <translation>
 
 (hinzugefuegt von Fahrplan, bitte vor Fahrantritt daten erneut pruefen)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="363"/>
+        <location filename="calendardialog.cpp" line="208"/>
         <source>&lt;br&gt;Entry is in the past!&lt;br&gt;</source>
         <translation>&lt;br&gt;Eintrag ist in der Vergangenheit!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="377"/>
+        <location filename="calendardialog.cpp" line="224"/>
         <source>&lt;br&gt;Entry added to the </source>
         <translation>&lt;br&gt;Eintrag wurde zum </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="377"/>
+        <location filename="calendardialog.cpp" line="224"/>
         <source> calendar.&lt;br&gt;</source>
         <translation> Kalender hinzugefügt.&lt;br&gt;</translation>
     </message>
-    <message>
-        <location filename="mainwindow.cpp" line="403"/>
-        <source>Select target calendar</source>
-        <translation>Ziel Kalender wählen</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="437"/>
-        <source>Thank you for Donating!</source>
-        <translation>Danke fürs spenden!</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="443"/>
-        <source>by smurfy (maemo@smurfy.de)&lt;br&gt;Version </source>
-        <translation>von smurfy (maemo@smurfy.de)&lt;br&gt;Version </translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="443"/>
-        <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
-        <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="445"/>
-        <source>About Fahrplan</source>
-        <translation>Über Fahrplan</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="472"/>
-        <source>&lt;br&gt;Details already loading, please wait.&lt;br&gt;</source>
-        <translation>&lt;br&gt;Details werden bereits geladen, bitte warten.&lt;br&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="486"/>
-        <source>&lt;br&gt;Error opening the details.&lt;br&gt;</source>
-        <translation>&lt;br&gt;Beim öffnen der Details ist ein Fehler aufgetreten.&lt;br&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="492"/>
-        <source>Details</source>
-        <translation>Details</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="501"/>
-        <source>Add to calendar</source>
-        <translation>In Kalender eintragen</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="583"/>
-        <source>&lt;br&gt;&lt;b&gt;Duration: &lt;/b&gt;</source>
-        <translation>&lt;br&gt;&lt;b&gt;Dauer: &lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="618"/>
-        <source>&lt;br&gt;No results found.&lt;br&gt;</source>
-        <translation>&lt;br&gt;Keine Ergebnisse gefunden.&lt;br&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="637"/>
-        <source>Results</source>
-        <translation>Ergebnis</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="654"/>
-        <source>to</source>
-        <translation>nach</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="665"/>
-        <source>Earlier</source>
-        <translation>Früher</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="671"/>
-        <source>Later</source>
-        <translation>Später</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="684"/>
-        <source> transfer</source>
-        <translation> umstieg</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="687"/>
-        <source> transfers</source>
-        <translation> umstiege</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="706"/>
-        <source>&lt;br&gt;OnTime</source>
-        <translation>&lt;br&gt;Pünktlich</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="844"/>
-        <source>&lt;br&gt;Please select a from and to station and make sure they are not the same.&lt;br&gt;</source>
-        <translation>&lt;br&gt;Bitte zwei verschiedene Haltestellen wählen.&lt;br&gt;</translation>
-    </message>
 </context>
 <context>
     <name>configDialog</name>
