@@ -195,7 +195,7 @@ MainWindow::MainWindow(QWidget *parent)
     {
         QMessageBox::about(this,
                            tr("Welcome to a new version of fahrplan this has changed"),
-                           tr("- bahn.de: adding train restrictions<br>- Calendar: you can select to which calendar you want add the journey.<br>- last used stationnames could be filled automatically on startup.<br>- Added a Donate link to the mainmenu")
+                           tr("- bahn.de: fixed gps search<br>- making sure the Birthdays calendar will not be displayed as a valid target calendar.")
                            );
 
         settings->setValue("firstLaunch", APP_VER);
@@ -292,141 +292,10 @@ void MainWindow::stationArrivalClicked()
     selectDialog->show();
 }
 
-void MainWindow::addToCalendar(QString calendarname)
-{
-    CMulticalendar *multiCalendar = CMulticalendar::MCInstance();
-
-    int pErrorCode;
-    CCalendar *calendar = multiCalendar->getCalendarByName(calendarname.toStdString(), pErrorCode);
-
-    if (!calendar)
-    {
-        return;
-    }
-
-    QString title       = tr("Journey: ") + lastSearchDetails.items.first().fromStation + tr(" to ") + lastSearchDetails.items.last().toStation;
-    QString description = lastSearchDetails.items.first().fromStation + tr(" to ") + lastSearchDetails.items.last().toStation + "\n";
-
-    if (lastSearchDetails.info != "")
-    {
-        description.append(lastSearchDetails.info + "\n");
-    }
-    if (lastSearchDetails.duration != "")
-    {
-        description.append(tr("Duration: ") + lastSearchDetails.duration + "\n");
-    }
-
-    description.append("\n");
-
-    foreach(DetailResultItem item, lastSearchDetails.items)
-    {
-        if (item.train != "")
-        {
-            description.append(item.train + "\n");
-        }
-
-        description.append( item.fromStation );
-
-        if (item.fromInfo != "")
-        {
-            description.append(" - " + item.fromInfo + "\n");
-        } else
-        {
-            description.append("\n");
-        }
-
-        description.append( item.toStation );
-
-        if (item.toInfo != "")
-        {
-            description.append(" - " + item.toInfo);
-        }
-
-        if (item.info != "")
-        {
-            description.append("\n" + item.info);
-        }
-
-        description.append("\n\n");
-    }
-
-    description.append(tr("\n\n(added by fahrplan app, please recheck informations before travel.)"));
-
-    title       = fahrplanUtils::removeUmlauts(title);
-    description = fahrplanUtils::removeUmlauts(description);
-
-    QDateTime tsFrom = lastSearchDetails.items.first().fromTime;
-    QDateTime tsTo   = lastSearchDetails.items.last().toTime;
-
-    if (tsFrom.toTime_t() < QDateTime::currentDateTime().toTime_t())
-    {
-        QMaemo5InformationBox::information(this, tr("<br>Entry is in the past!<br>"), QMaemo5InformationBox::DefaultTimeout);
-        return;
-    } else
-    {
-        qDebug() <<title;
-        qDebug() <<tsFrom.toString("dd.MM.yyyy hh:mm");
-        qDebug() <<tsTo.toString("dd.MM.yyyy hh:mm");
-        qDebug() <<description;
-
-        CEvent *pEvent = new CEvent(title.toStdString(), description.toStdString(), "", tsFrom.toTime_t(), tsTo.toTime_t());
-        int errorCode = 0;
-
-        multiCalendar->addEvent(pEvent, calendar->getCalendarId(), errorCode);
-
-        QMaemo5InformationBox::information(this, tr("<br>Entry added to the ") + calendarname + tr(" calendar.<br>"), QMaemo5InformationBox::DefaultTimeout);
-    }
-}
-
-void MainWindow::selectTargetCalendar(QStringList items)
-{
-    //If only one entry found we directly use it.
-    if (items.count() == 1)
-    {
-        addToCalendar(items[0]);
-        this->hide();
-        return;
-    }
-
-    QStandardItemModel * tmpModel = new QStandardItemModel(0, 1);
-
-    QString string;
-    foreach(string, items)
-    {
-        //qDebug() << "- " << string;
-        QStandardItem *item = new QStandardItem(string);
-        item->setTextAlignment(Qt::AlignCenter);
-        item->setEditable(false);
-        tmpModel->appendRow(item);
-    }
-
-    QMaemo5ValueButton *tmpButton = new QMaemo5ValueButton(tr("Select target calendar"));
-    tmpButton->setValueLayout(QMaemo5ValueButton::ValueBesideText);
-    QMaemo5ListPickSelector *tmpSelector = new QMaemo5ListPickSelector;
-    connect(tmpSelector, SIGNAL(selected(QString)), this, SLOT(addToCalendar(QString)));
-    tmpSelector->setModel(tmpModel);
-    tmpButton->setPickSelector(tmpSelector);
-    tmpButton->click();
-}
-
 void MainWindow::alarmButtonClicked()
 {
-    CMulticalendar *multiCalendar = CMulticalendar::MCInstance();
-    vector<CCalendar*> vector_of_cal  = multiCalendar->getListCalFromMc();
-    QVector<CCalendar*> qvector_of_cal = QVector< CCalendar  *>::fromStdVector(vector_of_cal); //
-    if(!qvector_of_cal.empty())
-    {
-        QStringList calendars;
-        foreach(CCalendar *ccal, qvector_of_cal )
-        {
-            if (!ccal->IsReadOnly())
-            {
-                calendars.append(QString::fromStdString(ccal->getCalendarName()));
-            }
-        }
-
-        selectTargetCalendar(calendars);
-    }
+    calendarDialog *calDlg = new calendarDialog(lastSearchDetails, this);
+    calDlg->open();
 }
 
 void MainWindow::donateButtonClicked()
