@@ -36,20 +36,15 @@
 #include <qgeopositioninfo.h>
 #include <qgeopositioninfosource.h>
 
-#include <calendar-backend/CCalendar.h>
-#include <calendar-backend/CMulticalendar.h>
-#include <calendar-backend/CEvent.h>
-#include <calendar-backend/CAlarm.h>
-
 #include "parser_abstract.h"
 #include "parser_mobilebahnde.h"
 #include "parser_mvvde.h"
 #include "parser_sbbch.h"
 #include "selectstationdialog.h"
 #include "configdialog.h"
-#include "fahrplanutils.h"
+#include "calendardialog.h"
 
-#define APP_VER "0.0.15"
+#define APP_VER "0.0.16"
 
 //Use the QtMobility namespace
 QTM_USE_NAMESPACE
@@ -87,8 +82,6 @@ private slots:
     void gpsButtonClicked();
     void windowDestroyed(QObject* obj = 0);
     void resultItemClicked();
-    void selectTargetCalendar(QStringList items);
-    void addToCalendar(QString calendarname);
 
 private:
     QPushButton        *searchButton;
