@@ -562,6 +562,10 @@ QStringList parserMobileBahnDe::getStationsByGPS(qreal latitude, qreal longitude
                       sLatitude +
                       "&performLocating=2&tpl=stopsnear&look_maxdist=1000&look_stopclass=1023&n=1";
 
+    qDebug()<<"GPS REQUEST URL:"<<fullUrl;
+
+    qDebug()<<"GPS RAW VALUES: LAT"<<latitude<<" LONG:"<<longitude;
+
     QUrl url(fullUrl);
 
     http->setHost(url.host(), QHttp::ConnectionModeHttp, url.port() == -1 ? 0 : url.port());
@@ -586,7 +590,7 @@ QStringList parserMobileBahnDe::getStationsByGPS(qreal latitude, qreal longitude
     QXmlQuery query;
     query.bindVariable("path", &readBuffer);
     //Query for Gps infos
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div[@class='overview']/div/a[@class='uLine']/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/div/a[@class='uLine']/string()");
 
     QStringList result;
     if (!query.evaluateTo(&result))
